@@ -7,21 +7,21 @@ from imjoy_rpc import api
 class ImJoyPlugin:
     """Represent an ImJoy plugin."""
 
-    def authorizer(self, user_info, context):
-        """Authorize users."""
-        return True
-
     async def setup(self):
         """Set up the plugin."""
         token = await api.generateToken()
-        assert token["token"]
-        print(f'Generated token: {token["token"]}')
+        assert "@imjoy@" in token
+        print(f"Generated token: {token}")
 
-        await api.register_service(
-            {"name": "echo service", "echo": lambda x: print("echo: " + str(x))}
+        service_id = await api.register_service(
+            {
+                "name": "echo service",
+                "type": "echo",
+                "echo": lambda x: print("echo: " + str(x)),
+            }
         )
-        service = await api.get_services({"name": "echo service"})
-        await service[0].echo("a message")
+        service = await api.get_service(service_id)
+        await service.echo("a message")
         await api.log("initialized")
 
     async def run(self, ctx):
